chat

package
v0.0.0-...-dac94cf Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: MIT Imports: 40 Imported by: 0

Documentation

Index

Constants

const InitMemoryDisplayText = "Refresh the repo's shared Agency memory."

Variables

var DeleteKeyMaps = DeleteAttachmentKeyMaps{
	AttachmentDeleteMode: key.NewBinding(
		key.WithKeys("ctrl+r"),
		key.WithHelp("ctrl+r+{i}", "delete attachment at index i"),
	),
	Escape: key.NewBinding(
		key.WithKeys("esc"),
		key.WithHelp("esc", "cancel delete mode"),
	),
	DeleteAllAttachments: key.NewBinding(
		key.WithKeys("r"),
		key.WithHelp("ctrl+r+r", "delete all attchments"),
	),
}

Functions

func CreateTextArea

func CreateTextArea(existing *textarea.Model) textarea.Model

func NewEditorCmp

func NewEditorCmp(app *app.App) tea.Model

func NewMessagesCmp

func NewMessagesCmp(app *app.App) tea.Model

func NewSidebarCmp

func NewSidebarCmp(session session.Session, history history.Service, agencyService *app.AgencyService, teamService *team.Service, workers *orchestration.Manager) tea.Model

Types

type AgencyBroadcastMsg

type AgencyBroadcastMsg struct {
	app.BroadcastMsg
}

AgencyBroadcastMsg is a tea message carrying a live agent broadcast.

type AgencyBulletinMsg

type AgencyBulletinMsg struct {
	app.BulletinRecord
}

AgencyBulletinMsg is a tea message carrying a performance bulletin entry.

type AgencyOverview

type AgencyOverview struct {
	ProductName         string
	CurrentConstitution string
	SoloConstitution    string
	OfficeMode          string
	ConsensusMode       string
	SharedWorkplace     string
	RedisAddress        string
	LedgerPath          string
	LastEvent           string
	Blueprint           string
	TeamTemplate        string
	Governance          string
	Topology            string
	WorkspaceMode       string
	RequiredGates       []string
	GenesisSummary      string
	ManufacturedRoles   int
	ThreadSource        string
	Running             bool
	DefaultQuorum       int
	TeamName            string
	Leader              string
	UnreadDirect        int
	UnreadBroadcasts    int
	PendingHandoffs     int
	MemberCount         int
	WorkerCount         int
	ActiveWorkerCount   int
	BoardSummary        map[string]int
	Thread              []string
	Constitutions       []string
	HasOfficeState      bool
	HasTeamSnapshot     bool
}

func InspectAgencyOverview

func InspectAgencyOverview(appState *app.App) AgencyOverview

type ApprovalCmp

type ApprovalCmp struct {
	// contains filtered or unexported fields
}

func NewApprovalCmp

func NewApprovalCmp(a *app.App, orgID string) *ApprovalCmp

func (*ApprovalCmp) BindingKeys

func (m *ApprovalCmp) BindingKeys() []key.Binding

func (*ApprovalCmp) GetSize

func (m *ApprovalCmp) GetSize() (int, int)

func (*ApprovalCmp) HasPendingApprovals

func (m *ApprovalCmp) HasPendingApprovals() bool

HasPendingApprovals returns true when there are proposals waiting for a vote.

func (*ApprovalCmp) Init

func (m *ApprovalCmp) Init() tea.Cmd

func (*ApprovalCmp) SetSize

func (m *ApprovalCmp) SetSize(width, height int) tea.Cmd

func (*ApprovalCmp) Update

func (m *ApprovalCmp) Update(msg tea.Msg) (tea.Model, tea.Cmd)

func (*ApprovalCmp) View

func (m *ApprovalCmp) View() string

type ApprovalProposalMsg

type ApprovalProposalMsg struct {
	app.ProposalMsg
}

ApprovalProposalMsg is a tea message carrying a pending action proposal.

type ApprovalVotedMsg

type ApprovalVotedMsg struct {
	ProposalID string
	Approved   bool
}

ApprovalVotedMsg is emitted when the user casts a vote on a proposal.

type DeleteAttachmentKeyMaps

type DeleteAttachmentKeyMaps struct {
	AttachmentDeleteMode key.Binding
	Escape               key.Binding
	DeleteAllAttachments key.Binding
}

type EditorFocusMsg

type EditorFocusMsg bool

type EditorKeyMaps

type EditorKeyMaps struct {
	Send       key.Binding
	OpenEditor key.Binding
}

type MessageKeys

type MessageKeys struct {
	PageDown     key.Binding
	PageUp       key.Binding
	HalfPageUp   key.Binding
	HalfPageDown key.Binding
}

type SendMsg

type SendMsg struct {
	Text        string
	DisplayText string
	Attachments []message.Attachment
}

type SessionClearedMsg

type SessionClearedMsg struct{}

type SessionSelectedMsg

type SessionSelectedMsg = session.Session

type SplashModeChangedMsg

type SplashModeChangedMsg struct {
	Active bool
}

Jump to